---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: ''
assignees: ''

---

<!-- Please describe the issue in detail here, and fill in the fields below -->

### Reproducing code example:

<!-- A short code example that reproduces the problem/missing feature. It should be
self-contained, i.e., possible to run as-is via 'python myproblem.py' -->

```python
import pysindy
<< your code here >>
```

### Error message:

<!-- Full error message, if any (starting from line Traceback: ...) -->

### PySINDy/Python version information:

<!-- Output from 'import sys, pysindy; print(pysindy.__version__, sys.version)' -->
